/*   FILE: template.h -- 
 * AUTHOR: W. Michael Petullo <new@flyn.org>
 *   DATE: 16 January 2000
 *
 * Copyright (c) 1999 W. Michael Petullo <new@flyn.org>
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef TEMPLATE_H
#define TEMPLATE_H

#ifdef __cplusplus
extern "C" {
#endif
/* Bit mask values for the opts argument to template_write. */
#define TEMPLATE_FORCE 0x1	/* Overwrite existing file. */
#define TEMPLATE_USE_GLOBAL 0x2	/* Ignore local templates. */
/* ============================= template_init () =========================== *//* Initializes the template library. */
	void template_init(void);

/* ============================= template_set_global_dir () ================= */
/* Set the global template directory -- takes a full path. */
    int template_set_global_dir(const char *path);

/* ============================= template_set_local_dir () ================== */
/* Set the local template directory -- takes a directory to concatenate onto 
 * the user's home directory.
 */
    int template_set_local_dir(const char *dir);

/* ============================= template_list () =========================== */
/* Prints the templates associated with the given filename.  Returns 0 in 
 * the case of an error.
 */
    int template_list(const char *filename);

/* ============================= template_write () ========================== */
/* Creates a file from a template given a filename to create,
 * template_name (try ``default''), and an option bitmask.  Returns 0 in the
 * case of an error.
 */
    int template_write(const char *filename, const char *template_name,
		       const int opts);

/* ============================= template_parse_err () ====================== */
/* Returns true if a parse error has occured while processing. */
    int template_parse_err(void);

/* ============================= template_parse_perror () =================== */
/* Dequeues a parse error and prints it. */
    void template_parse_perror(char *msg);

/* ============================= template_parse_strerror () ================= */
/* Dequeues and returns a parse error or NULL. */
    char *template_parse_strerror(void);

/* ============================= template_perror () ========================= */
/* Prints the last non-parse error. */
    void template_perror(char *msg);

/* ============================= template_strerror () ======================= */
/* Returns the last non-parse error. */
    char *template_strerror(void);

/* ============================= template_destroy () ======================== */
/* Releases the resources associated with the template library. */
    void template_destroy(void);

#ifdef __cplusplus
}
#endif
#endif				/* TEMPLATE_H */
